查找条目 | Lires
Description: Lires documentations

Skip to content

# 查找条目 ​

通过筛选，在数据库中查找所需条目。

## 标签筛选 ​

标签筛选是最简单的筛选方式，只需要在主页面中选择左侧标签栏中相应的标签即可。 目前标签筛选只支持标签的交集，即同时满足所有标签的条目。

TIP

标签筛选需要对标签进行良好的维护， 如果不需要此功能，可以在设置中点击`️Tag Display`按钮，关闭标签功能。

## 内容搜索 ​

在主界面工具栏最右侧的搜索框中输入关键词，即可进行内容搜索筛选，输入内容不区分大小写，支持模糊匹配。 搜索结果会结合标签筛选的结果，以交集形式显示出符合条件的条目。

可以通过搜索栏旁的下拉菜单选择搜索的范围，包括标题、作者、笔记等。 下图显示了搜索栏的可选范围：

## 语义搜索 ​

通过选择搜索栏中的`feature`类型，可以基于条目特征进行向量搜索。 此时，并不会筛除数据，而是将语义上与搜索内容更相似度越高的条目排在前面。

INFO

向量提取 向量提取基于文献的摘要信息，因此建议在添加文献时，尽量添加摘要信息。 当文献没有摘要信息时，会依照AI摘要、全文、和标题的优先级顺序进行向量索引构建。

目前向量索引每12小时会更新一次，因此如果添加了新的文献，需要等待一段时间后才能进行向量搜索。

TIP

基于语义搜索，还可以进行相似文献发现。 在数据卡片的概览窗口和推送页面的推送卡片中，点击`related works`按钮，即可进行相似文献发现， 此时，数据卡片中会出现相似度评分，评分越高，相似度越高。

除此以外，软件还提供数据可视化功能，可以将数据卡片中的向量信息可视化为三维空间中的点云，方便进行数据分析。

通过开启设置中的`Scatter Plot`按钮，即可打开可视化页面，由于此时需要在服务器端进行数据处理， 因此开启可视化功能时，需要等待一段时间，直到数据处理完成。 如果在进行可视化时，进行向量搜索，会在可视化页面中以颜色显示出搜索结果与内容相似度的大小，如下图所示：

INFO

- 在数据库文献数量小于5时，无法绘制可视化图像。
- 开启可视化会增加带宽消耗，并且导致渲染开销增加，当数据量较大时，可能会导致页面卡顿。